package model;

import java.util.ArrayList;
import java.util.List;

public class CollisionSummary {

    private List<CollisionData > data; // all the collision data collected
    private int quadrants; // all the quadrants for which there is a collision

    public CollisionSummary() {
        data = new ArrayList<>();
        quadrants = 0;
    }

    public void addCollision(CollisionData data, int quadrants) {
        this.data.add(data);
        this.quadrants = this.quadrants | quadrants;
    }

    public int getQuadrants() {
        return quadrants;
    }

    public List<CollisionData> getData() {
        return data;
    }

    public boolean isCollision() {
        if (data.isEmpty()) return false;
        return true;
    }

    public boolean isCollisionTopRight() {
        return ((quadrants & CollisionData.QUADRANT_TOPRIGHT) >0);
    }

    public boolean isCollisionTopLeft() {
        return ((quadrants & CollisionData.QUADRANT_TOPLEFT) >0);
    }

    public boolean isCollisionTop() {
        return (isCollisionTopLeft() || isCollisionTopRight());
    }

    public boolean isCollisionWholeTop() {
        return (isCollisionTopLeft() && isCollisionTopRight());
    }

    public boolean isCollisionBottomRight() {
        return ((quadrants & CollisionData.QUADRANT_BOTTOMRIGHT) >0);
    }

    public boolean isCollisionBottomLeft() {
        return ((quadrants & CollisionData.QUADRANT_BOTTOMLEFT) >0);
    }

    public boolean isCollisionBottom() {
        return (isCollisionBottomLeft() || isCollisionBottomRight());
    }

    public boolean isCollisionWholeBottom() {
        return (isCollisionBottomLeft() && isCollisionBottomRight());
    }

    public boolean isCollisionLeft() {
        return (isCollisionTopLeft() || isCollisionBottomLeft());
    }

    public boolean isCollisionWholeLeft() {
        return (isCollisionTopLeft() && isCollisionBottomLeft());
    }

    public boolean isCollisionRight() {
        return (isCollisionTopRight() || isCollisionBottomRight());
    }

    public boolean isCollisionWholeRight() {
        return (isCollisionTopRight() && isCollisionBottomRight());
    }
}
