package model;

import java.util.ArrayList;
import java.util.List;

public class Model {

    // directions
    public static int LEFT = 0;
    public static int RIGHT = 1;
    public static int UP = 2;
    public static int DOWN = 3;
    private ManModel manModel;

    private long lastFrame; // used to regulate FPS
    private long frameGap; // used to regulate FPS
    private long frameCounter; // used to count frames
    private int width;
    private int height;
    private List<String> keyPressed;

    public Model(int width, int height) {
        this.width = width;
        this.height = height;
        lastFrame = -1;
        frameGap = 15000000;
        frameCounter = 0;
        keyPressed = new ArrayList<>();
        manModel = new ManModel();
        manModel.put(30,300);
    }

    public int getWidth() {
        return width;
    }

    public int getHeight() {
        return height;
    }

    public ManModel getMan() {
        return manModel;
    }

    public void setLastFrame(long lastFrame) {
        this.lastFrame = lastFrame;
    }

    public void incrementFrameCounter() {
        frameCounter++;
    }

    public long getFrameCounter() {
        return frameCounter;
    }

    public long getLastFrame() {
        return lastFrame;
    }

    public long getFrameGap() {
        return frameGap;
    }

    public void update() {
        manModel.update();
    }

    public void resetFlags() {
        manModel.resetFlags();
    }

    public String getLastKeyPressed() {
        if (keyPressed.isEmpty()) return "";
        return keyPressed.get(keyPressed.size()-1);
    }
    public void addKeyPressed(String lastKey) {
        if (!this.keyPressed.contains(lastKey)) {
            this.keyPressed.add(lastKey);
        }
    }
    public void removeKeyPressed(String lastKey) {
        this.keyPressed.remove(lastKey);
    }
    public int indexKeyPressed(String key) {
         return keyPressed.indexOf(key);
    }
    public boolean isKeyPressed() {
        return !keyPressed.isEmpty();
    }
}
