package view;

import javafx.scene.layout.*;
import javafx.scene.paint.Paint;
import javafx.scene.shape.Line;
import javafx.scene.shape.Rectangle;
import javafx.scene.shape.Shape;
import model.Model;

import java.util.ArrayList;
import java.util.List;

public class View {

    private Model model;
    private Pane rootPane;

    // window related attributes
    private int width;
    private int height;
    // look
    private ManLook manLook;
    private List<Obstacle> obstacles;

    public View(Model model) {

        this.model = model;
        width = model.getWidth();
        height = model.getHeight();

        obstacles = new ArrayList<>();

        manLook = new ManLook(model.getMan(), 20, this);

        // create north wall
        createRectangleObstacle("north wall",0,0,width, 10, 0);
        // create south wall
        createRectangleObstacle("south wall", 0,height-10,width, 10, 0);
        // create west wall
        createRectangleObstacle("west wall", 0,0,10,height, 0);
        // create east wall
        createRectangleObstacle("east wall", width-10,0,10,height, 0);
        // create platforms

        // NB: you can change the last parameters to test different angles (e.g. 1, 5, 10, 25, 45) to see how the Man behaves
        createRectangleObstacle("plat1", -25, height-210, 200, 10, 60);
        createRectangleObstacle("plat2", 100, height-100, 200, 10, 20);
        createRectangleObstacle("plat3",300, height-200, 100, 10, 0);

        rootPane = new Pane();
        rootPane.setPrefSize(width,height);

        rootPane.getChildren().add(manLook.getBody());
        for(Obstacle o : obstacles) {
            rootPane.getChildren().add(o.getShape());
        }
    }

    public int getWidth() {
        return width;
    }

    public int getHeight() {
        return height;
    }

    public Pane getRootPane() {
        return rootPane;
    }

    public ManLook getManLook() {
        return manLook;
    }

    public List<Obstacle> getObstacles() {
        return obstacles;
    }

    public void update() {
        manLook.update();
    }

    private void createRectangleObstacle(String name, double x, double y, double width, double height, double angle) {
        Rectangle r = new Rectangle(x,y,width, height);
        r.setRotate(angle);
        obstacles.add(new Obstacle(name, r));
    }
    private void createLineObstacle(String name, double x, double y, double xx, double yy) {
        Line l = new Line(x,y,xx,yy);
        obstacles.add(new Obstacle(name, l));
    }
}
